| Title: | 'R' Grammar for 'Tree-Sitter' |
|---|---|
| Description: | Provides bindings to an 'R' grammar for 'Tree-sitter', to be used alongside the 'treesitter' package. 'Tree-sitter' builds concrete syntax trees for source files of any language, and can efficiently update those syntax trees as the source file is edited. |
| Authors: | Davis Vaughan [aut, cre], Posit Software, PBC [cph, fnd], Tree-sitter authors [cph] (Tree-sitter C headers and parser.c) |
| Maintainer: | Davis Vaughan <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.2.0.9000 |
| Built: | 2026-05-21 20:55:11 UTC |
| Source: | https://github.com/r-lib/tree-sitter-r |
language() returns a tree_sitter_language object for R for use with the
treesitter package.
language()language()
A tree_sitter_language object.
language()language()